#! /usr/bin/env python
## netconf - A switch printer tool
## Copyright (C) 2002 Red Hat, Inc.
## Copyright (C) 2002 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sys

PROGDIR = '/usr/share/redhat-switch-printer/'

if not "/usr/lib/rhs/python" in sys.path:
    sys.path.append("/usr/lib/rhs/python")

if not PROGDIR in sys.path:
    sys.path.append(PROGDIR)

import signal
import os
import os.path
import string
import gettext

##
## I18N
##
PROGNAME = 'redhat-switch-printer'
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)

try:
    gettext.install(PROGNAME, '/usr/share/locale', 1)
except IOError:
    import __builtin__
    __builtin__.__dict__['_'] = unicode    

from functions import *

import gtk
import gtk.glade

class mainDialog:
    def __init__(self):
        pass

    def main(self):
        glade_file = 'redhat-switch-printer.glade'

        if not os.path.isfile(glade_file):
            glade_file = GLADEPATH + glade_file
        if not os.path.isfile(glade_file):
            glade_file = PROGDIR + glade_file

        self.xml = gtk.glade.XML(glade_file, None, domain=PROGNAME)

        self.xml.signal_autoconnect(
            {
            'on_cancelB_clicked' : self.on_cancelB_clicked,
            'on_okB_clicked' : self.on_okB_clicked,
            })

        self.dialog = self.xml.get_widget('window')
        self.lprng_widget = self.xml.get_widget('lprngRB')
        self.cups_widget = self.xml.get_widget('cupsRB')
        
        self.dialog.connect('delete-event', self.on_Dialog_delete_event)
        self.dialog.connect('hide', gtk.mainquit)
        self.load_icon('switch-printer.xpm', self.dialog)
        self.xml.get_widget('lprPixmap').set_from_file(PROGDIR+'pixmaps/switch-printer.png')

        self.hydrate()
        gtk.mainloop()
        
    def on_Dialog_delete_event(self, *args):
        gtk.mainquit()

    def on_cancelB_clicked(self, button):
        gtk.mainquit()

    def on_okB_clicked(self, button):
        if self.lprng_widget.get_active():
            switch(LPRNG)
        elif self.cups_widget.get_active():
            switch(CUPS)

        self.dialog.hide()
        self.infoDialog()
        gtk.mainquit()

    def hydrate(self):
        self.xml.get_widget('lprLabel').set_text(TEXT)
        self.xml.get_widget('frame').set_label(_('Available Printing System'))
        printer_list = get_printer()

        if len(printer_list) == 0:
            self.warningDialog()
            sys.exit(1)

        # show printer checkbox
        for printer in printer_list:
            if printer == PRINTER[LPRNG]:
                self.lprng_widget.show()
            if printer == PRINTER[CUPS]:
                self.cups_widget.show()

        # activate default printer
        printer = get_default_printer(printer_list)
        if printer == PRINTER[LPRNG]:
            self.lprng_widget.set_active(TRUE)
        elif printer == PRINTER[CUPS]:
                self.cups_widget.set_active(TRUE)

    def infoDialog(self):
        dlg = gtk.MessageDialog(self.dialog,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,                                
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                INFO_TEXT1)
        
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()

    def warningDialog(self):
        dlg = gtk.MessageDialog(self.dialog,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                WARNING_TEXT)
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()

    def get_pixbuf(self, pixmap_file):
        fn = pixmap_file
        if not os.path.exists(pixmap_file):
            pixmap_file = "pixmaps/" + fn
            if not os.path.exists(pixmap_file):
                pixmap_file = "../pixmaps/" + fn
                if not os.path.exists(pixmap_file):
                    pixmap_file = PROGDIR + fn
                    if not os.path.exists(pixmap_file):
                        pixmap_file = PROGDIR + "pixmaps/" + fn
                        if not os.path.exists(pixmap_file):
                            return None, None

        pixbuf = gtk.gdk.pixbuf_new_from_file(pixmap_file)

        return pixbuf

    def get_icon(self, pixmap_file, dialog):
        pixbuf = self.get_pixbuf(pixmap_file)
    
        pix, mask = pixbuf.render_pixmap_and_mask()
    
        return pix, mask

    def load_icon(self, pixmap_file, dialog):
        if not dialog: return
        
        pixbuf = self.get_pixbuf(pixmap_file)
        if not pixbuf: return
     
        dialog.set_icon(pixbuf)

    def rootWarning(self, errMsg):
        dlg = gtk.MessageDialog(None,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                errMsg)
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()
        
# make ctrl-C work
if __name__ == '__main__':
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    dlg = mainDialog().main()
    
    sys.exit(0)
